@@ -13,7 +13,7 @@ use mixed_num::traits::*;
 /// 
 /// TODO 
 fn atan_poly_1<T>( y: T, x: T ) -> T
-    where T: MixedNum + MixedNumSigned
+    where T: MixedNum + MixedNumSigned + MixedPowi + MixedNumConversion<i32> + MixedNumConversion<f32> + MixedOps
 {
     let phi = (x*y) / ( x.mixed_powi(2) + T::mixed_from_num( 0.28125 )*y.mixed_powi(2) );
     return phi;
@@ -32,7 +32,7 @@ fn atan_poly_1<T>( y: T, x: T ) -> T
 /// 
 /// TODO 
 fn atan_poly_2<T>( y: T, x: T ) -> T
-    where T: MixedNum + MixedNumSigned
+    where T: MixedNum + MixedNumSigned + MixedPowi + MixedNumConversion<f32> + MixedOps
 {
     let phi     = (x*y) / ( y.mixed_powi( 2) + T::mixed_from_num( 0.28125 )*x.mixed_powi(2) );
     return phi;
@@ -73,7 +73,7 @@ fn atan_poly_2<T>( y: T, x: T ) -> T
 /// ![Alt version](https://github.com/ErikBuer/Fixed-Trigonometry/blob/main/figures/atan2_comparisons.png?raw=true)
 /// 
 pub fn atan2<T>( y: T, x: T ) -> T
-    where T:  MixedNum + MixedNumSigned
+    where T:  MixedNum + MixedNumSigned + MixedOps + MixedAbs + MixedPi + MixedReal + MixedPowi
 {
     // Precompute
     let y_abs = y.mixed_abs();
@@ -192,7 +192,7 @@ pub fn atan2<T>( y: T, x: T ) -> T
 /// ![Alt version](https://github.com/ErikBuer/Fixed-Trigonometry/blob/main/figures/atan_error_comparisons.png?raw=true)
 /// 
 pub fn atan<T>( x: T ) -> T
-    where T: MixedNum + MixedNumSigned
+    where T:  MixedNum + MixedNumSigned + MixedOps + MixedAbs + MixedPi + MixedReal + MixedPowi
 {
     return atan2(x,T::mixed_from_num(1));
 }
\ No newline at end of file
